@@ -1,11 +1,16 @@
+import sys
+sys.path.append( '../../../' )
 import os
 import shutil
 from pathlib import Path
+import time
+from src.comm.docker_ver import *
+path_home = '/localpath/' if docker_ver() else str(Path.home())
+ref_path = '/localpath/' if docker_ver() else ''
 
 class Local(object):
 	"""docstring for Storage"""
 	def __init__(self):
-		# super(Storage, self).__init__()
 		self.type = "local"
 		self.dataset = "./"
 		self.credentials = {}
@@ -14,11 +19,16 @@ class Local(object):
 		# transforms to absolute path
 		if location[0] == '~':
 			if len(location) > 1:
-				location = str(Path.home())+location[1:]
+				location = path_home+location[1:]
 			else:
-				location = str(Path.home())
-		location = str(os.path.abspath(location))
-		print('Initializing dataset at '+location)
+				location = path_home
+		if location[0] != '/':
+			location = str(os.path.abspath(location))
+
+		if ref_path == '/localpath/':
+			location = ref_path + '/' + location
+
+		#print('Initializing dataset at '+location)
 		if location[-1] != '/':
 			location = location + '/'
 		if not os.path.exists(location):
@@ -95,22 +105,21 @@ class Local(object):
 		path = self.dataset+filename
 		metadata = {
 			'key' : self.dataset+filename,
-			'date_loaded' : os.path.getmtime(path),
-			'date_added' : os.path.getctime(path),
-			'last_modified' : os.path.getmtime(path),
+			'date_loaded' : time.strftime("%m/%d/%Y, %H:%M:%S", time.gmtime(os.path.getmtime(path))),
+			'date_added' : time.strftime("%m/%d/%Y, %H:%M:%S", time.gmtime(os.path.getctime(path))),
+			'last_modified' : time.strftime("%m/%d/%Y, %H:%M:%S", time.gmtime(os.path.getmtime(path))),
 		}
 		return metadata
 
 	def loadDataset(self):
 		file_m = []
-		print()
 		for root, dirs, files in os.walk(self.dataset, topdown=False):
 			for name in files:
 				path = os.path.join(root, name)
 				if path[-1] != '/':
 					metadata = {
 						'key' : path,
-						'last_modified' : os.path.getmtime(path)
+						'last_modified' : time.strftime("%m/%d/%Y, %H:%M:%S", time.gmtime(os.path.getmtime(path)))
 					}
 					file_m.append(metadata)
 		return file_m
@@ -126,7 +135,7 @@ class Local(object):
 		for root, dirs, files in os.walk(path, topdown=False):
 			for name in files:
 				keys.append(os.path.join(root, name))
-				last_m.append(os.path.getmtime(os.path.join(root, name)))
+				last_m.append(time.strftime("%m/%d/%Y, %H:%M:%S", time.gmtime(os.path.getmtime(os.path.join(root, name)))))
 		return keys, last_m
 
 	def listFilesinDataset(self):
